.. emsuite documentation master file, created by
   sphinx-quickstart on Wed Jan 14 18:18:27 2026.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.


Potential
=========

.. note::

   This module is under development and will be available in a future release.

.. toctree::
   :maxdepth: 1
   :hidden:

   tutorials/index
   how-to/index
   reference/index
   explanation/index

The **potential** module will generate electrostatic potential maps 
of chemical systems.

.. code-block:: bash

   emsuite -p input_file.in

Check back soon for updates.

